COUNTRIES = [
    {
        "id": 1,
        "name": "Afghanistan"
    },
    {
        "id": 2,
        "name": "Algeria"
    },
    {
        "id": 3,
        "name": "American Samoa"
    },
    {
        "id": 4,
        "name": "Andorra"
    },
    {
        "id": 5,
        "name": "Angola"
    },
    {
        "id": 7,
        "name": "Albania"
    },
    {
        "id": 8,
        "name": "Antarctica"
    },
    {
        "id": 10,
        "name": "Argentina"
    },
    {
        "id": 11,
        "name": "Armenia"
    },
    {
        "id": 12,
        "name": "Aruba"
    },
    {
        "id": 13,
        "name": "Australia"
    },
    {
        "id": 14,
        "name": "Austria"
    },
    {
        "id": 15,
        "name": "Azerbaidjan"
    },
    {
        "id": 17,
        "name": "Bangladesh"
    },
    {
        "id": 19,
        "name": "Belgium"
    },
    {
        "id": 20,
        "name": "Belize"
    },
    {
        "id": 21,
        "name": "Benin"
    },
    {
        "id": 24,
        "name": "Bolivia"
    },
    {
        "id": 25,
        "name": "Bosnia Herzegovina"
    },
    {
        "id": 26,
        "name": "Botswana"
    },
    {
        "id": 28,
        "name": "Brazil"
    },
    {
        "id": 30,
        "name": "Brunei Darussalam"
    },
    {
        "id": 31,
        "name": "Bulgaria"
    },
    {
        "id": 32,
        "name": "Bahrain"
    },
    {
        "id": 33,
        "name": "Burkina Faso"
    },
    {
        "id": 34,
        "name": "Burundi"
    },
    {
        "id": 35,
        "name": "Buthan"
    },
    {
        "id": 36,
        "name": "Cambodia"
    },
    {
        "id": 37,
        "name": "Cameroon"
    },
    {
        "id": 38,
        "name": "Canada"
    },
    {
        "id": 39,
        "name": "Cape Verde"
    },
    {
        "id": 41,
        "name": "Central African Rep"
    },
    {
        "id": 42,
        "name": "Chad"
    },
    {
        "id": 43,
        "name": "Chile"
    },
    {
        "id": 44,
        "name": "China"
    },
    {
        "id": 47,
        "name": "Colombia"
    },
    {
        "id": 48,
        "name": "Congo"
    },
    {
        "id": 49,
        "name": "Cook Islands"
    },
    {
        "id": 50,
        "name": "Costa Rica"
    },
    {
        "id": 51,
        "name": "Cuba"
    },
    {
        "id": 52,
        "name": "Cyprus"
    },
    {
        "id": 53,
        "name": "Czech Republic"
    },
    {
        "id": 54,
        "name": "Djibouti"
    },
    {
        "id": 55,
        "name": "Denmark"
    },
    {
        "id": 57,
        "name": "Ecuador"
    },
    {
        "id": 58,
        "name": "Egypt"
    },
    {
        "id": 59,
        "name": "El Salvador"
    },
    {
        "id": 60,
        "name": "Equatorial Guinea"
    },
    {
        "id": 61,
        "name": "Estonia"
    },
    {
        "id": 62,
        "name": "Ethiopia"
    },
    {
        "id": 63,
        "name": "Finland"
    },
    {
        "id": 64,
        "name": "Falkland Island"
    },
    {
        "id": 65,
        "name": "Faroe Islands"
    },
    {
        "id": 66,
        "name": "Fiji"
    },
    {
        "id": 67,
        "name": "France"
    },
    {
        "id": 70,
        "name": "Gabon"
    },
    {
        "id": 71,
        "name": "Georgia"
    },
    {
        "id": 72,
        "name": "Germany"
    },
    {
        "id": 73,
        "name": "Ghana"
    },
    {
        "id": 74,
        "name": "Gibraltar"
    },
    {
        "id": 76,
        "name": "Greece"
    },
    {
        "id": 77,
        "name": "Guatemala"
    },
    {
        "id": 78,
        "name": "Greenland"
    },
    {
        "id": 79,
        "name": "Gambia"
    },
    {
        "id": 81,
        "name": "Guadeloupe"
    },
    {
        "id": 83,
        "name": "Guinea"
    },
    {
        "id": 84,
        "name": "Guinea Bissau"
    },
    {
        "id": 85,
        "name": "Guyana"
    },
    {
        "id": 86,
        "name": "Hong Kong"
    },
    {
        "id": 87,
        "name": "Haiti"
    },
    {
        "id": 89,
        "name": "Honduras"
    },
    {
        "id": 90,
        "name": "Croatia"
    },
    {
        "id": 91,
        "name": "Hungary"
    },
    {
        "id": 92,
        "name": "Iceland"
    },
    {
        "id": 93,
        "name": "India"
    },
    {
        "id": 94,
        "name": "Indonesia"
    },
    {
        "id": 95,
        "name": "Iran"
    },
    {
        "id": 96,
        "name": "Iraq"
    },
    {
        "id": 97,
        "name": "Ireland"
    },
    {
        "id": 98,
        "name": "Israel"
    },
    {
        "id": 99,
        "name": "Italy"
    },
    {
        "id": 102,
        "name": "Japan"
    },
    {
        "id": 103,
        "name": "Jordan"
    },
    {
        "id": 104,
        "name": "Kazachstan"
    },
    {
        "id": 105,
        "name": "Kenya"
    },
    {
        "id": 106,
        "name": "Kyrgyzstan"
    },
    {
        "id": 107,
        "name": "Kiribati"
    },
    {
        "id": 108,
        "name": "Comoros"
    },
    {
        "id": 109,
        "name": "Korea North"
    },
    {
        "id": 110,
        "name": "Korea South"
    },
    {
        "id": 111,
        "name": "Kuwait"
    },
    {
        "id": 112,
        "name": "Laos"
    },
    {
        "id": 113,
        "name": "Latvia"
    },
    {
        "id": 114,
        "name": "Lebanon"
    },
    {
        "id": 115,
        "name": "Lesotho"
    },
    {
        "id": 116,
        "name": "Liberia"
    },
    {
        "id": 117,
        "name": "Libya"
    },
    {
        "id": 118,
        "name": "Liechtenstein"
    },
    {
        "id": 119,
        "name": "Lithuania"
    },
    {
        "id": 120,
        "name": "Luxembourg"
    },
    {
        "id": 121,
        "name": "Macau"
    },
    {
        "id": 122,
        "name": "Madagascar"
    },
    {
        "id": 123,
        "name": "Malawi"
    },
    {
        "id": 124,
        "name": "Malaysia"
    },
    {
        "id": 125,
        "name": "Maldives"
    },
    {
        "id": 126,
        "name": "Mali"
    },
    {
        "id": 127,
        "name": "Marshall Islands"
    },
    {
        "id": 128,
        "name": "Martinique"
    },
    {
        "id": 129,
        "name": "Mauritania"
    },
    {
        "id": 130,
        "name": "Mauritius"
    },
    {
        "id": 131,
        "name": "Mexico"
    },
    {
        "id": 132,
        "name": "Micronesia"
    },
    {
        "id": 133,
        "name": "Moldavia"
    },
    {
        "id": 134,
        "name": "Monaco"
    },
    {
        "id": 136,
        "name": "Malta"
    },
    {
        "id": 137,
        "name": "Morocco"
    },
    {
        "id": 138,
        "name": "Mozambique"
    },
    {
        "id": 139,
        "name": "Myanmar"
    },
    {
        "id": 140,
        "name": "Mongolia"
    },
    {
        "id": 141,
        "name": "Namibia"
    },
    {
        "id": 142,
        "name": "Nauru"
    },
    {
        "id": 143,
        "name": "Nepal"
    },
    {
        "id": 144,
        "name": "Netherland Antilles"
    },
    {
        "id": 145,
        "name": "Netherlands"
    },
    {
        "id": 147,
        "name": "New Caledonia"
    },
    {
        "id": 148,
        "name": "Nicaragua"
    },
    {
        "id": 149,
        "name": "Niger"
    },
    {
        "id": 150,
        "name": "Nigeria"
    },
    {
        "id": 151,
        "name": "Niue"
    },
    {
        "id": 152,
        "name": "New Zealand"
    },
    {
        "id": 153,
        "name": "Norfolk Island"
    },
    {
        "id": 155,
        "name": "Norway"
    },
    {
        "id": 156,
        "name": "Oman"
    },
    {
        "id": 157,
        "name": "Pakistan"
    },
    {
        "id": 158,
        "name": "Palau"
    },
    {
        "id": 159,
        "name": "Panama"
    },
    {
        "id": 160,
        "name": "Papua New Guinea"
    },
    {
        "id": 161,
        "name": "Paraguay"
    },
    {
        "id": 162,
        "name": "Peru"
    },
    {
        "id": 163,
        "name": "Philippines"
    },
    {
        "id": 165,
        "name": "Poland"
    },
    {
        "id": 166,
        "name": "French Polynesia"
    },
    {
        "id": 167,
        "name": "Portugal"
    },
    {
        "id": 169,
        "name": "Qatar"
    },
    {
        "id": 170,
        "name": "Reunion"
    },
    {
        "id": 171,
        "name": "Romania"
    },
    {
        "id": 172,
        "name": "Russia"
    },
    {
        "id": 173,
        "name": "Rwanda"
    },
    {
        "id": 176,
        "name": "San Marino"
    },
    {
        "id": 177,
        "name": "Saudi Arabia"
    },
    {
        "id": 178,
        "name": "Senegal"
    },
    {
        "id": 179,
        "name": "Seychelles"
    },
    {
        "id": 180,
        "name": "Sudan"
    },
    {
        "id": 181,
        "name": "Sierra_Leone"
    },
    {
        "id": 182,
        "name": "Slovakia"
    },
    {
        "id": 183,
        "name": "Slovenia"
    },
    {
        "id": 184,
        "name": "Solomon Islands"
    },
    {
        "id": 185,
        "name": "Somalia"
    },
    {
        "id": 186,
        "name": "Suriname"
    },
    {
        "id": 187,
        "name": "South Africa"
    },
    {
        "id": 189,
        "name": "Spain"
    },
    {
        "id": 190,
        "name": "Sri Lanka"
    },
    {
        "id": 191,
        "name": "St Helena"
    },
    {
        "id": 192,
        "name": "St Pierre And Miquelon"
    },
    {
        "id": 193,
        "name": "Sao Tome and Principe"
    },
    {
        "id": 196,
        "name": "Swaziland"
    },
    {
        "id": 197,
        "name": "Sweden"
    },
    {
        "id": 198,
        "name": "Singapore"
    },
    {
        "id": 199,
        "name": "Switzerland"
    },
    {
        "id": 200,
        "name": "Syria"
    },
    {
        "id": 201,
        "name": "Tadjikistan"
    },
    {
        "id": 202,
        "name": "Taiwan"
    },
    {
        "id": 203,
        "name": "Tanzania"
    },
    {
        "id": 204,
        "name": "Ukraine"
    },
    {
        "id": 205,
        "name": "Thailand"
    },
    {
        "id": 206,
        "name": "Togolese Republic"
    },
    {
        "id": 207,
        "name": "Tokelau"
    },
    {
        "id": 208,
        "name": "Tonga Islands"
    },
    {
        "id": 209,
        "name": "East Timor"
    },
    {
        "id": 211,
        "name": "Tunisia"
    },
    {
        "id": 212,
        "name": "Turkey"
    },
    {
        "id": 213,
        "name": "Turkmenistan"
    },
    {
        "id": 215,
        "name": "Tuvalu"
    },
    {
        "id": 216,
        "name": "Uganda"
    },
    {
        "id": 217,
        "name": "United Arab Emirates"
    },
    {
        "id": 218,
        "name": "United Kingdom"
    },
    {
        "id": 219,
        "name": "United States"
    },
    {
        "id": 220,
        "name": "Uruguay"
    },
    {
        "id": 222,
        "name": "Uzbekistan"
    },
    {
        "id": 223,
        "name": "Vanuatu"
    },
    {
        "id": 224,
        "name": "Vatican City State"
    },
    {
        "id": 225,
        "name": "Venezuela"
    },
    {
        "id": 226,
        "name": "Vietnam"
    },
    {
        "id": 229,
        "name": "Wallis And Futuna Island"
    },
    {
        "id": 230,
        "name": "Samoa"
    },
    {
        "id": 231,
        "name": "Yemen"
    },
    {
        "id": 232,
        "name": "Yugoslavia"
    },
    {
        "id": 234,
        "name": "Zambia"
    },
    {
        "id": 235,
        "name": "Zimbabwe"
    },
    {
        "id": 236,
        "name": "Zaire"
    },
    {
        "id": 237,
        "name": "Barbados"
    },
    {
        "id": 238,
        "name": "Jamaica"
    },
    {
        "id": 239,
        "name": "South Sudan"
    },
    {
        "id": 243,
        "name": "Palestine"
    },
    {
        "id": 244,
        "name": "Belarus"
    },
    {
        "id": 245,
        "name": "England"
    },
    {
        "id": 246,
        "name": "Scotland"
    },
    {
        "id": 247,
        "name": "Wales"
    },
    {
        "id": 248,
        "name": "Northern Ireland"
    },
    {
        "id": 249,
        "name": "Dominican Republic"
    },
    {
        "id": 250,
        "name": "Montenegro"
    },
    {
        "id": 251,
        "name": "Republic Of Macedonia"
    },
    {
        "id": 252,
        "name": "Anguilla"
    },
    {
        "id": 253,
        "name": "Antigua And Barbuda"
    },
    {
        "id": 254,
        "name": "Bahamas"
    },
    {
        "id": 255,
        "name": "Bermuda"
    },
    {
        "id": 256,
        "name": "British Indian Ocean Territory"
    },
    {
        "id": 257,
        "name": "British Virgin Islands"
    },
    {
        "id": 258,
        "name": "Cayman Islands"
    },
    {
        "id": 259,
        "name": "Christmas Island"
    },
    {
        "id": 260,
        "name": "Cocos Islands"
    },
    {
        "id": 261,
        "name": "Curacao"
    },
    {
        "id": 262,
        "name": "Dominica"
    },
    {
        "id": 263,
        "name": "Eritrea"
    },
    {
        "id": 264,
        "name": "Grenada"
    },
    {
        "id": 265,
        "name": "Guam"
    },
    {
        "id": 266,
        "name": "Guernsey"
    },
    {
        "id": 267,
        "name": "Isle Of Man"
    },
    {
        "id": 268,
        "name": "Ivory Coast"
    },
    {
        "id": 269,
        "name": "Jersey"
    },
    {
        "id": 270,
        "name": "Kosovo"
    },
    {
        "id": 271,
        "name": "Mayotte"
    },
    {
        "id": 272,
        "name": "Montserrat"
    },
    {
        "id": 273,
        "name": "Northern Mariana Islands"
    },
    {
        "id": 274,
        "name": "Pitcairn"
    },
    {
        "id": 275,
        "name": "Puerto Rico"
    },
    {
        "id": 276,
        "name": "Saint Barthelemy"
    },
    {
        "id": 277,
        "name": "Saint Kitts And Nevis"
    },
    {
        "id": 278,
        "name": "Saint Lucia"
    },
    {
        "id": 279,
        "name": "Saint Martin"
    },
    {
        "id": 280,
        "name": "Saint Vincent And The Grenadines"
    },
    {
        "id": 281,
        "name": "Serbia"
    },
    {
        "id": 282,
        "name": "Sint Maarten"
    },
    {
        "id": 283,
        "name": "Svalbard And JanMayen"
    },
    {
        "id": 284,
        "name": "Trinidad And Tobago"
    },
    {
        "id": 285,
        "name": "Turks And Caicos Islands"
    },
    {
        "id": 286,
        "name": "US Virgin Islands"
    },
    {
        "id": 287,
        "name": "Western Sahara"
    }
]
